@@ -39,8 +39,7 @@ class ApplicationRunner:
         rotation_backups = config.get('rotation_backups', 6)
         stdout = config.get('stdout', True)
 
-        logger = logging.getLogger('')
-
+        logger = logging.root
         formatter = logging.Formatter(fmt)
 
         file_handler = TimedRotatingFileHandler(
@@ -49,13 +48,12 @@ class ApplicationRunner:
             interval=rotation_interval,
             backupCount=rotation_backups,
         )
-        file_handler.setLevel(level)
         file_handler.setFormatter(formatter)
         logger.addHandler(file_handler)
 
         if stdout:
             handler = logging.StreamHandler()
-            handler.setLevel(level)
             handler.setFormatter(formatter)
-
             logger.addHandler(handler)
+
+        logger.setLevel(level)
